@@ -20,6 +20,7 @@
 
 import traceback
 import warnings
+from cStringIO import StringIO
 
 plugins = ['base', 'opendocument', 'pdf', 'chart']
 
@@ -27,9 +28,13 @@ for name in plugins:
     try:
         __import__('relatorio.templates.%s' % name)
     except Exception, e:
-        warnings.warn("Unable to load plugin '%s', you will not be able "
-                      "to use it" % name)
-        print 'Original traceback'
-        print '-' * 80
-        print
-        traceback.print_exc()
+        tb_file = StringIO()
+
+        print >> tb_file, ("Unable to load plugin '%s', you will not be able "
+                           "to use it" % name)
+        print >> tb_file
+        print >> tb_file, 'Original traceback:'
+        print >> tb_file, '-------------------'
+        traceback.print_exc(file=tb_file)
+        print >> tb_file
+        warnings.warn(tb_file.getvalue())
